@@ -6,7 +6,7 @@ from .Config import Config
 
 
 class Image:
-    def __init__(self, image=None, path=""):
+    def __init__(self, image):
         if image: 
             self.image = image
         if path:
@@ -14,43 +14,48 @@ class Image:
 
         self.process()
 
+    @classmethod
+    def fromFileName(cls, filename):
+        data = Image.seek(path)
+        return cls(data)  
+
     def get(self):
         return self.image
 
     
-    def decode(self, image):
+    def decode(image):
         image_bytes = base64.b64decode(image)
         image = BytesIO(image_bytes)
         return PilImage.open(image).convert('L')
 
-    def encode(self, image):
+    def encode(image):
         image = base64.b64encode(image)
         return image
     
 
-    def resize(self,image):
+    def resize(image):
         image = np.uint8(image)
         image = PilImage.fromarray(image).resize((Config("IMAGE_WIDTH"), Config("IMAGE_HEIGHT")))
         return np.array(image)
 
-    def normalize(self, image):
+    def normalize(image):
         return image / 255
 
     def process(self):
-        image = self.decode(self.image)
+        image = Image.decode(self.image)
         image = np.array(image)
         if Config("RESIZE_ENABLED"):
-            image = self.resize(image)
+            image = Image.resize(image)
         if Config("NORMALIZATION_ENABLED"):
-            image = self.normalize(image)
+            image = Image.normalize(image)
         image = image[np.newaxis, ..., np.newaxis]
         self.image = image
         return image
 
-    def seek(self, path):
+    def seek(path):
         image = PilImage.open(path).convert('L')
         im_file = BytesIO()
         image.save(im_file, format="JPEG")
-        return self.encode(im_file.getvalue())
+        return Image.encode(im_file.getvalue())
 
     
\ No newline at end of file
